summaryrefslogtreecommitdiffstats
path: root/macosx/ttkMacOSXTheme.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-08-27 10:24:45 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-08-27 10:24:45 (GMT)
commitc9ab6b090e48fa0dc6e18194dc636fdd47de179b (patch)
tree4ae74afd0e81f6472d1bcdd20de04616f80632f0 /macosx/ttkMacOSXTheme.c
parentad908843c78dcba5e13e8c616a6d795619b6fe60 (diff)
downloadtk-c9ab6b090e48fa0dc6e18194dc636fdd47de179b.zip
tk-c9ab6b090e48fa0dc6e18194dc636fdd47de179b.tar.gz
tk-c9ab6b090e48fa0dc6e18194dc636fdd47de179b.tar.bz2
Some internal master -> container renamings, nothing related to API
Diffstat (limited to 'macosx/ttkMacOSXTheme.c')
-rw-r--r--macosx/ttkMacOSXTheme.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/macosx/ttkMacOSXTheme.c b/macosx/ttkMacOSXTheme.c
index 0259a55..37d3631 100644
--- a/macosx/ttkMacOSXTheme.c
+++ b/macosx/ttkMacOSXTheme.c
@@ -242,11 +242,11 @@ static CGFloat blackRGBA[4] = {0.0, 0.0, 0.0, 1.0};
* GetBackgroundColor --
*
* Fills the array rgba with the color coordinates for a background color.
* Start with the background color of a window's geometry master, or the
* standard ttk window background if there is no master. If the contrast
* parameter is nonzero, modify this color to be darker, for the aqua
* appearance, or lighter for the DarkAqua appearance. This is primarily
* used by the Fill and Background elements.
*/
static void GetBackgroundColor(
@@ -255,18 +255,18 @@ static void GetBackgroundColor(
int contrast,
CGFloat *rgba)
{
- TkWindow *winPtr = (TkWindow *) tkwin;
- TkWindow *masterPtr = (TkWindow *) TkGetGeomMaster(tkwin);
+ TkWindow *winPtr = (TkWindow *)tkwin;
+ TkWindow *containerPtr = (TkWindow *)TkGetGeomMaster(tkwin);
- while (masterPtr && masterPtr->privatePtr) {
- if (masterPtr->privatePtr->flags & TTK_HAS_CONTRASTING_BG) {
+ while (containerPtr && containerPtr->privatePtr) {
+ if (containerPtr->privatePtr->flags & TTK_HAS_CONTRASTING_BG) {
break;
}
- masterPtr = (TkWindow *) TkGetGeomMaster(masterPtr);
+ containerPtr = (TkWindow *)TkGetGeomMaster(containerPtr);
}
- if (masterPtr && masterPtr->privatePtr) {
+ if (containerPtr && containerPtr->privatePtr) {
for (int i = 0; i < 4; i++) {
- rgba[i] = masterPtr->privatePtr->fillRGBA[i];
+ rgba[i] = containerPtr->privatePtr->fillRGBA[i];
}
} else {
if ([NSApp macOSVersion] > 101300) {
@@ -242,11 +242,11 @@ static CGFloat blackRGBA[4] = {0.0, 0.0, 0.0, 1.0};
*
* Fills the array rgba with the color coordinates for a background color.
- * Start with the background color of a window's geometry master, or the
- * standard ttk window background if there is no master. If the contrast
- * parameter is nonzero, modify this color to be darker, for the aqua
- * appearance, or lighter for the DarkAqua appearance. This is primarily
- * used by the Fill and Background elements.
+ * Start with the background color of a window's geometry container, or
+ * the standard ttk window background if there is no container. If the
+ * contrast parameter is nonzero, modify this color to be darker, for the
+ * aqua appearance, or lighter for the DarkAqua appearance. This is
+ * primarily used by the Fill and Background elements.
*/
static void GetBackgroundColor(